@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2022 The Cacti Group                                 |
+ | Copyright (C) 2004-2023 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -39,22 +39,46 @@ html_start_box(__('About Cacti'), '100%', '', '3', 'center', '');
 	<td valign='top' class='odd' class='textArea'>
 		<div style='float:right;'><a href='http://www.cacti.net/'><img class='right' src='images/cacti_about_logo.gif' alt='raXnet'></a></div>
 
-		<p><?php print __('Cacti is designed to be a complete graphing solution based on the RRDtool\'s framework. Its goal is to make a network administrator\'s job easier by taking care of all the necessary details necessary to create meaningful graphs.'); ?></p>
+		<p><?php print __('Cacti is designed to be a complete graphing solution based on the RRDtool Time Series Database (TSDB) and Graphing solution. Its goal is to make the Network Administrator\'s job easier by taking care of all the important details necessary to create meaningful Graphs.'); ?></p>
 
-		<p><?php print __('Please see the official %sCacti website%s for information, support, and updates.', '<a href="http://www.cacti.net/?version=' . CACTI_VERSION . '">', '</a>'); ?></p>
+		<p><?php print __('Please see the official %sCacti website%s for information on how to use Cacti, get support, and updates.', '<a href="http://www.cacti.net/?version=' . CACTI_VERSION . '">', '</a>'); ?></p>
 
-		<p><strong><?php print __('Cacti Developers'); ?></strong><br>
+		<div class='flexContainer'>
+		<div class='flexChild' style='min-width:300px;'>
+		<p><strong><?php print __('Active Developers'); ?></strong></p>
+		<p style='min-height:45px'><?php print __('Developers working on Cacti, its Architecture, Documentation and Future Releases.'); ?></strong></p>
+		<ul type='disc'>
+			<li>Larry Adams <i>(TheWitness)</i></li>
+			<li>Mark Brugnoli-Vinten <i>(netniV)</i></li>
+			<li>Jimmy Conner <i>(cigamit)</i></li>
+			<li>Petr Macek <i>(xmacan)</i></li>
+			<li>Andreas Braun <i>(browniebraun)</i></li>
+			<li>Thomas Urban <i>(phalek)</i></li>
+			<li>Jing Chen <i>(ddb4github)</i></li>
+		</ul>
+		</div>
+		<div class='flexChild' style='min-width:300px;'>
+		<p><strong><?php print __('Honorable Mentions'); ?></strong></p>
+		<p style='min-height:45px'><?php print __('Contributors to Docuemntation, QA, Packaging, the Forums and our YouTube page.'); ?></strong></p>
+		<ul type='disc'>
+			<li>Sean Mancini <i>(bmfmancini)</i></li>
+			<li>J.P. Pasnak, CD <i>(Linegod)</i></strong></li>
+			<li>Chris Bell (Windows) <i>(BSOD2600)</i></li>
+			<li>Paul Gevers (Debian) <i>(paulgevers)</i></strong></li>
+			<li>Morten Stevens (Fedora) <i>(mortenstevens)</i></strong></li>
+		</ul>
+		</div>
+		<div class='flexChild' style='min-width:300px;'>
+		<p><strong><?php print __('Emeritus Members'); ?></strong></p>
+		<p style='min-height:45px'><?php print __('Members of the original Cacti Group that have since moved on in their careers.  We continue to wish them the best.'); ?></strong></p>
 		<ul type='disc'>
 			<li>Ian Berry <i>(raX)</i></li>
-			<li>Larry Adams <i>(TheWitness)</i></li>
-			<li>Tony Roman <i>(rony)</i></strong></li>
-			<li>J.P. Pasnak, CD <i>(Linegod)</i></strong></li>
-			<li>Jimmy Conner <i>(cigamit)</i></li>
 			<li>Reinhard Scheck <i>(gandalf)</i></li>
-			<li>Andreas Braun <i>(browniebraun)</i></li>
-			<li>Mark Brugnoli-Vinten <i>(netniV)</i></li>
+			<li>Tony Roman <i>(rony)</i></strong></li>
+			<li>Andy Blyler <i>(ablyler)</i></strong></li>
 		</ul>
-		</p>
+		</div>
+		</div>
 
 		<p><strong><?php print __('Thanks'); ?></a></strong><br>
 		<ul type='disc'>
