@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2022 The Cacti Group                                 |
+ | Copyright (C) 2004-2023 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -199,7 +199,7 @@ function form_save() {
 		$save['sysName']       = get_nfilter_request_var('sysName');
 		$save['sysOid']        = get_nfilter_request_var('sysOid');
 		if (function_exists('filter_var')) {
-			$save['sysDescr'] = filter_var($save['sysDescr'], FILTER_SANITIZE_STRING);
+			$save['sysDescr'] = filter_var($save['sysDescr'], FILTER_SANITIZE_FULL_SPECIAL_CHARS);
 		} else {
 			$save['sysDescr'] = strip_tags($save['sysDescr']);
 		}
