@@ -85,7 +85,7 @@ if (cacti_sizeof($parms)) {
 
 	foreach($parms as $parameter) {
 		if (strpos($parameter, '=')) {
-			list($arg, $value) = explode('=', $parameter);
+			list($arg, $value) = explode('=', $parameter, 2);
 		} else {
 			$arg = $parameter;
 			$value = '';
@@ -282,6 +282,7 @@ if (cacti_sizeof($parms)) {
 				exit(1);
 			}
 
+			break;
 		case '--version':
 		case '-V':
 		case '-v':
