@@ -57,7 +57,7 @@ $force      = false;
 if (cacti_sizeof($parms)) {
 	foreach($parms as $parameter) {
 		if (strpos($parameter, '=')) {
-			list($arg, $value) = explode('=', $parameter);
+			list($arg, $value) = explode('=', $parameter, 2);
 		} else {
 			$arg = $parameter;
 			$value = '';
@@ -204,6 +204,7 @@ if (cacti_sizeof($data_queries)) {
 		$i++;
 	}
 
+	set_config_option('reindex_last_run_time', time());
 	unregister_process('reindex', 'master');
 
 }
