@@ -2,7 +2,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2021 The Cacti Group                                 |
+ | Copyright (C) 2004-2023 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -23,30 +23,13 @@
  +-------------------------------------------------------------------------+
 */
 
-/* work with both Cacti 1.x and Cacti 0.8.x */
-if (file_exists(__DIR__ . '/../include/cli_check.php')) {
-	require(__DIR__ . '/../include/cli_check.php');
-} elseif (file_exists(__DIR__ . '/../include/global.php')) {
-	/* do NOT run this script through a web browser */
-	if (!isset($_SERVER['argv'][0]) || isset($_SERVER['REQUEST_METHOD'])  || isset($_SERVER['REMOTE_ADDR'])) {
-		die('<br>This script is only meant to run at the command line.');
-	}
+require(__DIR__ . '/../include/cli_check.php');
 
-	$no_http_headers = true;
-
-	require(__DIR__ . '/../include/global.php');
-} else {
-	print "FATAL: Can not initialize the Cacti API" . PHP_EOL;
+if ($config['poller_id'] > 1) {
+	print "FATAL: This utility is designed for the main Data Collector only" . PHP_EOL;
 	exit(1);
 }
 
-// For legacy Cacti behavior
-if (!function_exists('cacti_sizeof')) {
-	function cacti_sizeof($object) {
-		return cacti_sizeof($object);
-	}
-}
-
 if (!function_exists('get_cacti_cli_version')) {
 	function get_cacti_cli_version() {
 		return db_fetch_cell('SELECT cacti FROM version');
@@ -103,7 +86,7 @@ array_shift($parms);
 if (cacti_sizeof($parms)) {
 	foreach($parms as $parameter) {
 		if (strpos($parameter, '=')) {
-			list($arg, $value) = explode('=', $parameter);
+			list($arg, $value) = explode('=', $parameter, 2);
 		} else {
 			$arg = $parameter;
 			$value = '';
@@ -242,7 +225,7 @@ if (strlen($response)) {
 	$response_array = explode(' ', $response);
 	print 'NOTE: Using ' . $response_array[0] . ' Version ' . $response_array[1] . PHP_EOL;
 } else {
-	print 'FATAL: RRDTool not found in configuation or path.' . PHP_EOL . 'Please insure RRDTool can be found using one of these methods!' . PHP_EOL;
+	print 'FATAL: RRDTool not found in configuration or path.' . PHP_EOL . 'Please insure RRDTool can be found using one of these methods!' . PHP_EOL;
 	exit(-1);
 }
 
@@ -867,7 +850,7 @@ function preProcessXML(&$output) {
 					$row = strpos($line, '<row>');
 
 					if ($row > 0) {
-						$date = trim(substr($line,$comment_start+30,11));
+						$date = trim(substr($line,strpos($line,'/')+1,11));
 					}
 
 					if ($comment_start == 0) {
@@ -966,7 +949,7 @@ function loadTable($db, &$records) {
 
 function display_version() {
 	if (!defined('COPYRIGHT_YEARS')) {
-		define('COPYRIGHT_YEARS', '2004-2021');
+		define('COPYRIGHT_YEARS', '2004-2023');
 	}
 
 	$version = get_cacti_cli_version();
