@@ -342,7 +342,7 @@ function api_get_graphs_from_datasource($local_data_id) {
 		AND data_template_rrd.local_data_id = ?', array($local_data_id)), 'id', 'name');
 }
 
-function api_duplicate_graph($_local_graph_id, $_graph_template_id, $graph_title) {
+function api_duplicate_graph($_local_graph_id, $_graph_template_id, $graph_title, $map_to_data_query = true) {
 	global $struct_graph, $struct_graph_item;
 
 	if (!empty($_local_graph_id)) {
@@ -351,6 +351,10 @@ function api_duplicate_graph($_local_graph_id, $_graph_template_id, $graph_title
 			WHERE id = ?',
 			array($_local_graph_id));
 
+		if (!cacti_sizeof($graph_local)) {
+			return false;
+		}
+
 		$graph_template_graph = db_fetch_row_prepared('SELECT *
 			FROM graph_templates_graph
 			WHERE local_graph_id = ?',
@@ -377,6 +381,10 @@ function api_duplicate_graph($_local_graph_id, $_graph_template_id, $graph_title
 			WHERE id = ?',
 			array($_graph_template_id));
 
+		if (!cacti_sizeof($graph_template)) {
+			return false;
+		}
+
 		$graph_template_graph  = db_fetch_row_prepared('SELECT *
 			FROM graph_templates_graph
 			WHERE graph_template_id = ?
@@ -479,7 +487,7 @@ function api_duplicate_graph($_local_graph_id, $_graph_template_id, $graph_title
 
 	if (!empty($_local_graph_id)) {
 		update_graph_title_cache($local_graph_id);
-	} else {
+	} elseif ($map_to_data_query) {
 		// Graph Template, Check for Data Query Associated Graph Template
 		$data_query_graphs = db_fetch_assoc_prepared('SELECT *
 			FROM snmp_query_graph
@@ -580,6 +588,14 @@ function api_duplicate_graph($_local_graph_id, $_graph_template_id, $graph_title
 	 * for Caching.
 	 */
 	set_config_option('time_last_change_graph', time());
+
+	if ($_local_graph_id > 0) {
+		return $local_graph_id;
+	} elseif ($_graph_template_id > 0) {
+		return $graph_template_id;
+	} else {
+		return false;
+	}
 }
 
 function api_graph_change_device($local_graph_id, $host_id) {
