@@ -119,7 +119,7 @@ function dsdebug_poller_output(&$rrd_update_array) {
 				foreach($rrd_update_array as $item) {
 					if ($c['datasource'] == $item['local_data_id']) {
 						if (isset($item['times'][key($item['times'])])) {
-							$c['info'] = unserialize($c['info'], array('allowed_classes' => false));
+							$c['info'] = cacti_unserialize($c['info']);
 							$c['info']['last_result'] = $item['times'][key($item['times'])];
 							$c['info'] = serialize($c['info']);
 							db_execute_prepared('UPDATE data_debug SET `info` = ? WHERE `id` = ?', array($c['info'], $c['id']));
@@ -157,7 +157,7 @@ function dsdebug_poller_bottom() {
 
 		foreach ($checks as $c) {
 			$c['issue'] = array();
-			$info = unserialize($c['info'], array('allowed_classes' => false));
+			$info = cacti_unserialize($c['info']);
 
 			$dtd = db_fetch_row_prepared('SELECT *
 				FROM data_template_data
@@ -319,9 +319,9 @@ function dsdebug_poller_bottom() {
 					WHERE id = ?',
 					array($c['done'], $info, trim(implode("\n", $c['issue'])), $c['id']));
 			}
-
-			log_dsdebug_statistics('poller', cacti_sizeof($checks), $total_issues);
 		}
+
+		log_dsdebug_statistics('poller', cacti_sizeof($checks), $total_issues);
 	}
 
 	restore_error_handler();
@@ -334,7 +334,7 @@ function dsdebug_run_repair($id) {
 		array($id));
 
 	if (cacti_sizeof($check)) {
-		$check['info'] = unserialize($check['info'], array('allowed_classes' => false));
+		$check['info'] = cacti_unserialize($check['info']);
 
 		if (isset($check['info']['rrd_match_array']['tune'])) {
 			$path = get_data_source_path($id, true);
