@@ -109,12 +109,13 @@ function dsstats_debug($message) {
  *   and stores that information into the various database tables.
  *
  * @param $interval  - (string) either 'daily', 'weekly', 'monthly', or 'yearly'
+ * @param $type      - (string) the statistics type to store
  * @param $thread_id - (int) the dsstats parallel thread id
  *
  * @return - NULL
  */
-function dsstats_get_and_store_ds_avgpeak_values($interval, $thread_id = 1) {
-	global $config, $type;
+function dsstats_get_and_store_ds_avgpeak_values($interval, $type, $thread_id = 1) {
+	global $config;
 
 	global $total_user, $total_system, $total_real, $total_dsses;
 	global $user_time, $system_time, $real_time, $rrd_files;
@@ -434,8 +435,10 @@ function dsstats_obtain_data_source_avgpeak_values($rrdfile, $interval, &$pipes)
 
 								break;
 							} else {
-								foreach($position[$index] as $dsname => $stat) {
-									$dsvalues[$dsname][$stat] = trim($line);
+								if (isset($position[$index]) && cacti_sizeof($position[$index])) {
+									foreach($position[$index] as $dsname => $stat) {
+										$dsvalues[$dsname][$stat] = trim($line);
+									}
 								}
 							}
 						}
@@ -511,8 +514,8 @@ function dsstats_log_statistics($type) {
 
 		db_execute("DELETE FROM settings
 			WHERE name LIKE 'dsstats_rrd_%$sub_type%'
-			OR name LIKE 'dsstats_total_rrds_%$sub_type%'
-			OR name LIKE 'dsstats_total_dsses_%$sub_type%'");
+			OR name LIKE 'dsstats_total_rrds%_$sub_type%'
+			OR name LIKE 'dsstats_total_dsses%_$sub_type%'");
 	} else {
 		$cacti_stats = sprintf('Time:%01.2f Type:%s', $end-$start, $type);
 	}
@@ -689,11 +692,16 @@ function dsstats_poller_output(&$rrd_update_array) {
 			/* make the association between the multi-part name value pairs and the RRDfile internal
 			 * data source names.
 			 */
-			$ds_multi = array_rekey(db_fetch_assoc('SELECT DISTINCT data_name, data_source_name
-				FROM data_template_rrd AS dtr
-				INNER JOIN data_input_fields AS dif
-				ON dif.id = dtr.data_input_field_id
-				WHERE dtr.data_input_field_id != 0'), 'data_name', 'data_source_name');
+			$ds_multi = array_rekey(
+				db_fetch_assoc('SELECT DISTINCT data_name, data_source_name
+					FROM graph_templates_item AS gti
+					INNER JOIN data_template_rrd AS dtr
+					ON gti.task_item_id = dtr.id
+					INNER JOIN data_input_fields AS dif
+					ON dif.id = dtr.data_input_field_id
+					WHERE dtr.data_input_field_id != 0'),
+				'data_name', 'data_source_name'
+			);
 
 			/* required for updating tables */
 			$cache_i      = 1;
@@ -963,7 +971,7 @@ function dsstats_boost_bottom() {
 			sleep(2);
 		}
 
-		dsstats_get_and_store_ds_avgpeak_values('daily');
+		dsstats_get_and_store_ds_avgpeak_values('daily', 'child', 0);
 
 		dsstats_log_statistics('DAILY');
 	}
@@ -1148,6 +1156,7 @@ function dsstats_launch_children($type) {
 function dsstats_get_subtype($type) {
 	switch($type) {
 		case 'master':
+		case 'pmaster':
 			return 'child';
 			break;
 		case 'bmaster':
