@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2021 The Cacti Group                                 |
+ | Copyright (C) 2004-2023 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -25,10 +25,13 @@
 function graph_template_to_xml($graph_template_id) {
 	global $struct_graph, $fields_graph_template_input_edit, $struct_graph_item, $export_errors;
 
+	// Remote caching item
+	unset($struct_graph_item['data_template_id']);
+
 	$hash['graph_template'] = get_hash_version('graph_template') . get_hash_graph_template($graph_template_id);
 	$xml_text = '';
 
-	$graph_template = db_fetch_row_prepared('SELECT id, name
+	$graph_template = db_fetch_row_prepared('SELECT *
 		FROM graph_templates
 		WHERE id = ?',
 		array($graph_template_id));
@@ -61,7 +64,12 @@ function graph_template_to_xml($graph_template_id) {
 		return;
 	}
 
-	$xml_text .= '<hash_' . $hash['graph_template'] . ">\n\t<name>" . xml_character_encode($graph_template['name']) . "</name>\n\t<graph>\n";
+	$xml_text .= '<hash_' . $hash['graph_template'] . ">\n";
+	$xml_text .= "\t<name>"        . xml_character_encode($graph_template['name'])        . "</name>\n";
+	$xml_text .= "\t<multiple>"    . xml_character_encode($graph_template['multiple'])    . "</multiple>\n";
+	$xml_text .= "\t<test_source>" . xml_character_encode($graph_template['test_source']) . "</test_source>\n";
+
+	$xml_text .= "\t<graph>\n";
 
 	/* XML Branch: <graph> */
 	foreach ($struct_graph as $field_name => $field_array) {
@@ -920,7 +928,7 @@ function resolve_dependencies($type, $id, $dep_array) {
 					 * ATTENTION!
 					 * sequence of parameters matters!
 					 * we must place the newly found inherited items first
-					 * reason is, that during import, the leafes have to be tackled first,
+					 * reason is, that during import, the leaves have to be tackled first,
 					 * that is, the inherited items must be placed first so that they are "resolved" (decoded)
 					 * first during re-import */
 					$cdef_items = array_merge_recursive($inherited_cdef_items, $cdef_items);
