@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2021 The Cacti Group                                 |
+ | Copyright (C) 2004-2023 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -26,6 +26,7 @@ class Net_Ping
 {
 	var $socket;
 	var $host;
+	var $port;
 	var $ping_status;
 	var $ping_response;
 	var $snmp_status;
@@ -295,6 +296,16 @@ class Net_Ping
 			return false;
 		}
 
+		$result = $this->get_snmp_result($session, $oid);
+		if (!$result && $oid == '.1.3.6.1.2.1.1.3.0') {
+			$result = $this->get_snmp_result($session, '.1.3.6.1.6.3.10.2.1.3.0');
+		}
+
+		$session->close();
+		return $result;
+	}
+
+	function get_snmp_result($session, $oid) {
 		/* getnext does not work in php versions less than 5 */
 		if (($this->avail_method == AVAIL_SNMP_GET_NEXT) &&
 			(version_compare('5', phpversion(), '<'))) {
@@ -303,14 +314,12 @@ class Net_Ping
 			$output = cacti_snmp_session_get($session, $oid);
 		}
 
-		$session->close();
-
 		/* determine total time +- ~10% */
 		$this->time = $this->get_time($this->precision);
 
 		/* check result for uptime */
 		if ($output !== false && $output != 'U' && strlen($output)) {
-			/* calculte total time */
+			/* calculate total time */
 			$this->snmp_status   = $this->time*1000;
 			$this->snmp_response = 'Device responded to SNMP';
 
@@ -422,10 +431,10 @@ class Net_Ping
 
 						/* get the end time after the packet was received */
 						$this->time = $this->get_time($this->precision);
-							
+
 						$errno = socket_last_error($this->socket);
 						socket_clear_error($this->socket);
-						if (($code == -1 || empty($code)) && 
+						if (($code == -1 || empty($code)) &&
 							($errno == EHOSTUNREACH || $errno == ECONNRESET || $errno == ECONNREFUSED)) {
 
 							/* set the return message */
@@ -491,7 +500,7 @@ class Net_Ping
 				}
 			}
 
-			/* initilize the socket */
+			/* initialize the socket */
 			if (strpos($host_ip, ':') !== false) {
 				if (defined('AF_INET6')) {
 					if (version_compare(PHP_VERSION, '5.5.4', '<')) {
@@ -530,11 +539,11 @@ class Net_Ping
 					$this->ping_response = __('TCP ping: socket_connect(), reason: %s', socket_strerror($errno));
 					$this->ping_status   = 'down';
 
+					socket_clear_error($this->socket);
+
 					$this->close_socket();
 					$this->restore_cacti_error_handler();
 
-					socket_clear_error($this->socket);
-
 					return false;
 				}
 
@@ -648,19 +657,25 @@ class Net_Ping
 		}
 
 		/* snmp test */
-		if (($avail_method == AVAIL_SNMP_OR_PING) && ($ping_result == true)) {
-			$snmp_result = true;
-			$this->snmp_status = 0.000;
-		} elseif (($avail_method == AVAIL_SNMP_AND_PING) && ($ping_result == false)) {
-			$snmp_result = false;
-		} elseif (($avail_method == AVAIL_SNMP) || ($avail_method == AVAIL_SNMP_AND_PING) || ($avail_method == AVAIL_SNMP_OR_PING) || ($avail_method == AVAIL_SNMP_GET_SYSDESC) || ($avail_method == AVAIL_SNMP_GET_NEXT)) {
-			if (($this->host['snmp_community'] == '') && ($this->host['snmp_version'] != 3)) {
-				/* snmp version 1/2 without community string assume SNMP test to be successful
-				   due to backward compatibility issues */
+		if (($avail_method == AVAIL_SNMP) ||
+		   ($avail_method == AVAIL_SNMP_GET_SYSDESC) ||
+		   ($avail_method == AVAIL_SNMP_GET_NEXT) ||
+		   ($avail_method == AVAIL_SNMP_AND_PING) ||
+		   ($avail_method == AVAIL_SNMP_OR_PING)) {
+
+			/* If we are in AND mode and already have a failed ping result, we don't need SNMP */
+			if (!$ping_result && $avail_method == AVAIL_SNMP_AND_PING) {
+				$snmp_result = $ping_result;
+			} else {
+				/* Lets assume the host is up because if we are in OR mode then we have already
+				* pinged the host successfully, or some when silly people have not entered an
+				* snmp_community under v1/2, we assume that this was successfully anyway */
 				$snmp_result = true;
 				$this->snmp_status = 0.000;
-			} else {
-				$snmp_result = $this->ping_snmp();
+				if ($avail_method != AVAIL_SNMP_OR_PING &&
+				   (strlen($this->host['snmp_community']) > 0 || $this->host['snmp_version'] >= 3)) {
+					$snmp_result = $this->ping_snmp();
+				}
 			}
 		}
 
@@ -668,45 +683,15 @@ class Net_Ping
 
 		switch ($avail_method) {
 			case AVAIL_SNMP_OR_PING:
-				if (($this->host['snmp_community'] == '') && ($this->host['snmp_version'] != 3)) {
-					if ($ping_result) {
-						return true;
-					} else {
-						return false;
-					}
-				} elseif ($snmp_result) {
-					return true;
-				} elseif ($ping_result) {
-					return true;
-				} else {
-					return false;
-				}
+				return ($snmp_result || $ping_result);
 			case AVAIL_SNMP_AND_PING:
-				if (($this->host['snmp_community'] == '') && ($this->host['snmp_version'] != 3)) {
-					if ($ping_result) {
-						return true;
-					} else {
-						return false;
-					}
-				} elseif (($snmp_result) && ($ping_result)) {
-					return true;
-				} else {
-					return false;
-				}
+				return ($snmp_result && $ping_result);
 			case AVAIL_SNMP:
 			case AVAIL_SNMP_GET_NEXT:
 			case AVAIL_SNMP_GET_SYSDESC:
-				if ($snmp_result) {
-					return true;
-				} else {
-					return false;
-				}
+				return $snmp_result;
 			case AVAIL_PING:
-				if ($ping_result) {
-					return true;
-				} else {
-					return false;
-				}
+				return $ping_result;
 			default:
 				return false;
 		}
