@@ -568,76 +568,193 @@ function process_poller_output(&$rrdtool_pipe, $remainder = 0) {
 		/* create an array keyed off of each .rrd file */
 		foreach ($results as $item) {
 			/* trim the default characters, but add single and double quotes */
-			$value     = $item['output'];
-			$unix_time = $item['unix_time'];
-			$rrd_path  = $item['rrd_path'];
-			$rrd_name  = $item['rrd_name'];
+			$value            = $item['output'];
+			$unix_time        = $item['unix_time'];
+			$rrd_path         = $item['rrd_path'];
+			$rrd_name         = $item['rrd_name'];
+			$local_data_id    = $item['local_data_id'];
+			$data_template_id = $item['data_template_id'];
+			$rrd_tmpl         = '';
 
-			$rrd_update_array[$rrd_path]['local_data_id'] = $item['local_data_id'];
+			$rrd_update_array[$rrd_path]['local_data_id'] = $local_data_id;
 
-			/* single one value output */
-			if ((is_numeric($value)) || ($value == 'U')) {
+			if ((is_numeric($value)) || ($value == 'U' && $rrd_name != '')) {
+				/* single one value output */
 				$rrd_update_array[$rrd_path]['times'][$unix_time][$rrd_name] = $value;
-			/* special case of one value output: hexadecimal to decimal conversion */
 			} elseif (is_hexadecimal($value)) {
-				/* attempt to accomodate 32bit and 64bit systems */
+				/**
+				 * special case of one value output: hexadecimal to decimal conversion
+				 * attempt to accomodate 32bit and 64bit systems
+				 */
 				$value = str_replace(' ', '', $value);
+
 				if (strlen($value) <= 8 || ((2147483647+1) == intval(2147483647+1))) {
 					$rrd_update_array[$rrd_path]['times'][$unix_time][$rrd_name] = hexdec($value);
 				} elseif (function_exists('bcpow')) {
-					$dec = 0;
+					$dec    = 0;
 					$vallen = strlen($value);
+
 					for ($i = 1; $i <= $vallen; $i++) {
 						$dec = bcadd($dec, bcmul(strval(hexdec($value[$i - 1])), bcpow('16', strval($vallen - $i))));
 					}
+
 					$rrd_update_array[$rrd_path]['times'][$unix_time][$rrd_name] = $dec;
 				} else {
 					$rrd_update_array[$rrd_path]['times'][$unix_time][$rrd_name] = 'U';
 				}
-			/* multiple value output */
 			} elseif (strpos($value, ':') !== false) {
+				/* multiple value output */
 				$values = preg_split('/\s+/', $value);
 
+				if ($data_template_id > 0) {
+					$unused_data_source_names = array_rekey(
+						db_fetch_assoc_prepared('SELECT DISTINCT dtr.data_source_name, dtr.data_source_name
+							FROM data_template_rrd AS dtr
+							LEFT JOIN graph_templates_item AS gti
+							ON dtr.id = gti.task_item_id
+							WHERE dtr.local_data_id = ?
+							AND gti.task_item_id IS NULL',
+							array($local_data_id)),
+						'data_source_name', 'data_source_name'
+					);
+				} else {
+					$unused_data_source_names = array();
+				}
+
 				foreach($values as $value) {
 					$matches = explode(':', $value);
 
 					if (cacti_sizeof($matches) == 2) {
-						$fields = array();
-
 						if (isset($rrd_field_names[$item['data_template_id'] . '_' . $matches[0]])) {
-							$field_map = $rrd_field_names[$item['data_template_id'] . '_' . $matches[0]]['data_source_name'];
+							$field = $rrd_field_names[$item['data_template_id'] . '_' . $matches[0]]['data_source_name'];
 
-							if (strpos($field_map, ',') !== false) {
-								$fields = explode(',', $field_map);
-							} else {
-								$fields[] = $field_map;
+							if (cacti_sizeof($unused_data_source_names) && isset($unused_data_source_names[$field])) {
+								continue;
 							}
 
-							foreach($fields as $field) {
-								cacti_log("Parsed MULTI output field '" . $matches[0] . ':' . $matches[1] . "' [map " . $matches[0] . '->' . $field . ']' , true, 'POLLER', ($debug ? POLLER_VERBOSITY_NONE:POLLER_VERBOSITY_HIGH));
+							cacti_log("Parsed MULTI output field '" . $matches[0] . ':' . $matches[1] . "' [map " . $matches[0] . '->' . $field . ']' , true, 'POLLER', ($debug ? POLLER_VERBOSITY_NONE:POLLER_VERBOSITY_HIGH));
+
+							if (is_numeric($matches[1]) || ($matches[1] == 'U')) {
 								$rrd_update_array[$rrd_path]['times'][$unix_time][$field] = $matches[1];
+							} elseif ((function_exists('is_hexadecimal')) && (is_hexadecimal($matches[1]))) {
+								$rrd_update_array[$rrd_path]['times'][$unix_time][$field] = hexdec($matches[1]);
+							} else {
+								$rrd_update_array[$rrd_path]['times'][$unix_time][$field] = 'U';
 							}
+
+							$rrd_update_array[$rrd_path]['times'][$unix_time][$field] = $matches[1];
+
+							$rrd_tmpl .= ($rrd_tmpl != '' ? ':':'') . $field;
+
+							$rrd_update_array[$rrd_path]['template'] = $rrd_tmpl;
 						} else {
 							// Handle data source without a data template
-							$nt_rrd_field_names = array_rekey(
-								db_fetch_assoc_prepared('SELECT dtr.data_source_name, dif.data_name
-									FROM data_template_rrd AS dtr
-									INNER JOIN data_input_fields AS dif
-									ON dtr.data_input_field_id=dif.id
-									WHERE dtr.local_data_id = ?', array($item['local_data_id'])),
-								'data_name', 'data_source_name'
-							);
+							if ($data_template_id > 0) {
+								$nt_rrd_field_names = array_rekey(
+									db_fetch_assoc_prepared('SELECT DISTINCT dtr.data_source_name, dif.data_name
+										FROM graph_templates_item AS gti
+										INNER JOIN data_template_rrd AS dtr
+										ON gti.task_item_id = dtr.id
+										INNER JOIN data_input_fields AS dif
+										ON dtr.data_input_field_id = dif.id
+										WHERE dtr.local_data_id = ?',
+										array($local_data_id)),
+									'data_name', 'data_source_name'
+								);
+							} else {
+								$nt_rrd_field_names = array_rekey(
+									db_fetch_assoc_prepared('SELECT DISTINCT dtr.data_source_name, dif.data_name
+										FROM data_template_rrd AS dtr
+										INNER JOIN data_input_fields AS dif
+										ON dtr.data_input_field_id = dif.id
+										WHERE dtr.local_data_id = ?',
+										array($local_data_id)),
+									'data_name', 'data_source_name'
+								);
+							}
 
 							if (cacti_sizeof($nt_rrd_field_names)) {
 								if (isset($nt_rrd_field_names[$matches[0]])) {
-									cacti_log("Parsed MULTI output field '" . $matches[0] . ':' . $matches[1] . "' [map " . $matches[0] . '->' . $nt_rrd_field_names[$matches[0]] . ']' , true, 'POLLER', ($debug ? POLLER_VERBOSITY_NONE:POLLER_VERBOSITY_HIGH));
+									$field = $nt_rrd_field_names[$matches[0]];
 
-									$rrd_update_array[$item['rrd_path']]['times'][$unix_time][$nt_rrd_field_names[$matches[0]]] = $matches[1];
+									if (cacti_sizeof($unused_data_source_names) && isset($unused_data_source_names[$field])) {
+										continue;
+									}
+
+									cacti_log("Parsed MULTI output field '" . $matches[0] . ':' . $matches[1] . "' [map " . $matches[0] . '->' . $field . ']' , true, 'POLLER', ($debug ? POLLER_VERBOSITY_NONE:POLLER_VERBOSITY_HIGH));
+
+									if (is_numeric($matches[1]) || ($matches[1] == 'U')) {
+										$rrd_update_array[$rrd_path]['times'][$unix_time][$field] = $matches[1];
+									} elseif ((function_exists('is_hexadecimal')) && (is_hexadecimal($matches[1]))) {
+										$rrd_update_array[$rrd_path]['times'][$unix_time][$field] = hexdec($matches[1]);
+									} else {
+										$rrd_update_array[$rrd_path]['times'][$unix_time][$field] = 'U';
+									}
+
+									$rrd_tmpl .= ($rrd_tmpl != '' ? ':':'') . $field;
 								}
 							}
+
+							$rrd_update_array[$rrd_path]['template'] = $rrd_tmpl;
 						}
 					}
 				}
+			} else {
+				if ($data_template_id > 0) {
+					$unused_data_source_names = array_rekey(
+						db_fetch_assoc_prepared('SELECT DISTINCT dtr.data_source_name, dtr.data_source_name
+							FROM data_template_rrd AS dtr
+							LEFT JOIN graph_templates_item AS gti
+							ON dtr.id = gti.task_item_id
+							WHERE dtr.local_data_id = ?
+							AND gti.task_item_id IS NULL',
+							array($local_data_id)),
+						'data_source_name', 'data_source_name'
+					);
+
+					$nt_rrd_field_names = array_rekey(
+						db_fetch_assoc_prepared('SELECT DISTINCT dtr.data_source_name, dif.data_name
+							FROM graph_templates_item AS gti
+							INNER JOIN data_template_rrd AS dtr
+							ON gti.task_item_id = dtr.id
+							INNER JOIN data_input_fields AS dif
+							ON dtr.data_input_field_id = dif.id
+							WHERE dtr.local_data_id = ?',
+							array($local_data_id)),
+						'data_name', 'data_source_name'
+					);
+				} else {
+					$unused_data_source_names = array();
+
+					$nt_rrd_field_names = array_rekey(
+						db_fetch_assoc_prepared('SELECT DISTINCT dtr.data_source_name, dif.data_name
+							FROM data_template_rrd AS dtr
+							INNER JOIN data_input_fields AS dif
+							ON dtr.data_input_field_id = dif.id
+							WHERE dtr.local_data_id = ?',
+							array($local_data_id)),
+						'data_name', 'data_source_name'
+					);
+				}
+
+				$expected = '';
+
+				if (cacti_sizeof($nt_rrd_field_names)) {
+					foreach($nt_rrd_field_names as $field) {
+						if (cacti_sizeof($unused_data_source_names) && isset($unused_data_source_names[$field])) {
+							continue;
+						}
+
+						$expected .= ($expected != '' ? ' ':'') . "$field:value";
+
+						$rrd_update_array[$rrd_path]['times'][$unix_time][$field] = 'U';
+						$rrd_tmpl .= ($rrd_tmpl != '' ? ':':'') . $field;
+					}
+
+					$rrd_update_array[$rrd_path]['template'] = $rrd_tmpl;
+				}
+
+				cacti_log(sprintf('WARNING: Invalid output! MULTI DS[%d] Encountered [%s] Expected[%s]', $item['local_data_id'], $value, $expected), false, 'POLLER');
 			}
 
 			/* fallback values */
@@ -649,8 +766,9 @@ function process_poller_output(&$rrdtool_pipe, $remainder = 0) {
 		}
 
 		/* make sure each .rrd file has complete data */
-		$k = 0;
+		$k        = 0;
 		$data_ids = array();
+
 		foreach ($results as $item) {
 			$unix_time = $item['unix_time'];
 			$rrd_path  = $item['rrd_path'];
