@@ -184,8 +184,15 @@ function form_save() {
 
 		$package_name = import_package_get_name($xmlfile);
 
+		$details = import_package_get_details($xmlfile);
+		if (isset($details['class'])) {
+			$class = $details['class'];
+		} else {
+			$class = '';
+		}
+
 		/* obtain debug information if it's set */
-		$data = import_package($xmlfile, $profile_id, $remove_orphans, $replace_svalues, $preview_only, false, false, $hashes, $files);
+		$data = import_package($xmlfile, $profile_id, $remove_orphans, $replace_svalues, $preview_only, false, false, $hashes, $files, $class);
 
 		if ($preview_only) {
 			package_prepare_import_array($templates, $files, $package_name, $xmlfile, $data);
@@ -439,7 +446,7 @@ function package_validate_signature($xmlfile) {
 }
 
 function import_display_package_data($templates, $files, $package_name, $xmlfile, $data) {
-	global $config;
+	global $config, $device_classes;
 
 	$details = import_package_get_details($xmlfile);
 
@@ -455,6 +462,9 @@ function import_display_package_data($templates, $files, $package_name, $xmlfile
 		array(
 			'display' => __('Email')
 		),
+		array(
+			'display' => __('Device class')
+		),
 		array(
 			'display' => __('Version')
 		),
@@ -471,6 +481,11 @@ function import_display_package_data($templates, $files, $package_name, $xmlfile
 	form_selectable_cell($details['author'], $id);
 	form_selectable_cell($details['homepage'], $id);
 	form_selectable_cell($details['email'], $id);
+	if (isset($details['class']) && array_key_exists($details['class'], $device_classes)) {
+		form_selectable_cell($device_classes[$details['class']], $id);
+	} else {
+		form_selectable_cell(__('Unknown'), $id);
+	}
 	form_selectable_cell($details['version'], $id);
 	form_selectable_cell($details['copyright'], $id);
 	form_end_row();
